==> mingw-w64-i686-aws-sdk-cpp-1.9.307-1-any.pkg.tar.zst: mingw32/include/aws/lambda/model/SubnetIPAddressLimitReachedException.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lambda/Lambda_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Lambda
{
namespace Model
{

  /**
   * <p>Lambda was not able to set up VPC access for the Lambda function because one
   * or more configured subnets has no available IP addresses.</p><p><h3>See
   * Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/lambda-2015-03-31/SubnetIPAddressLimitReachedException">AWS
   * API Reference</a></p>
   */
  class AWS_LAMBDA_API SubnetIPAddressLimitReachedException
  {
  public:
    SubnetIPAddressLimitReachedException();
    SubnetIPAddressLimitReachedException(Aws::Utils::Json::JsonView jsonValue);
    SubnetIPAddressLimitReachedException& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    
    inline const Aws::String& GetType() const{ return m_type; }

    
    inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }

    
    inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }

    
    inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }

    
    inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }

    
    inline SubnetIPAddressLimitReachedException& WithType(const Aws::String& value) { SetType(value); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithType(const char* value) { SetType(value); return *this;}


    
    inline const Aws::String& GetMessage() const{ return m_message; }

    
    inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }

    
    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }

    
    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }

    
    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }

    
    inline SubnetIPAddressLimitReachedException& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithMessage(const char* value) { SetMessage(value); return *this;}

  private:

    Aws::String m_type;
    bool m_typeHasBeenSet;

    Aws::String m_message;
    bool m_messageHasBeenSet;
  };

} // namespace Model
} // namespace Lambda
} // namespace Aws

==> mingw-w64-i686-aws-sdk-cpp-1.10.19-1-any.pkg.tar.zst: mingw32/include/aws/lambda/model/SubnetIPAddressLimitReachedException.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lambda/Lambda_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Lambda
{
namespace Model
{

  /**
   * <p>Lambda couldn't set up VPC access for the Lambda function because one or more
   * configured subnets has no available IP addresses.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/lambda-2015-03-31/SubnetIPAddressLimitReachedException">AWS
   * API Reference</a></p>
   */
  class AWS_LAMBDA_API SubnetIPAddressLimitReachedException
  {
  public:
    SubnetIPAddressLimitReachedException();
    SubnetIPAddressLimitReachedException(Aws::Utils::Json::JsonView jsonValue);
    SubnetIPAddressLimitReachedException& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    
    inline const Aws::String& GetType() const{ return m_type; }

    
    inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }

    
    inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }

    
    inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }

    
    inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }

    
    inline SubnetIPAddressLimitReachedException& WithType(const Aws::String& value) { SetType(value); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithType(const char* value) { SetType(value); return *this;}


    
    inline const Aws::String& GetMessage() const{ return m_message; }

    
    inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }

    
    inline void SetMessage(const Aws::String& value) { m_messageHasBeenSet = true; m_message = value; }

    
    inline void SetMessage(Aws::String&& value) { m_messageHasBeenSet = true; m_message = std::move(value); }

    
    inline void SetMessage(const char* value) { m_messageHasBeenSet = true; m_message.assign(value); }

    
    inline SubnetIPAddressLimitReachedException& WithMessage(const Aws::String& value) { SetMessage(value); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithMessage(Aws::String&& value) { SetMessage(std::move(value)); return *this;}

    
    inline SubnetIPAddressLimitReachedException& WithMessage(const char* value) { SetMessage(value); return *this;}

  private:

    Aws::String m_type;
    bool m_typeHasBeenSet = false;

    Aws::String m_message;
    bool m_messageHasBeenSet = false;
  };

} // namespace Model
} // namespace Lambda
} // namespace Aws
